package es.uoc.mejoratuingles.db.adapters;


import java.util.*;

import android.util.Log;
import android.content.*;
import android.database.*;
import android.database.sqlite.*;



import es.uoc.mejoratuingles.db.*;
import es.uoc.mejoratuingles.beans.*;

public class LeccionAdapter {
	
	final String ID="ID";
	final String NOMBRE="NOMBRE";
	final String URL="URL";
	final String ENUNCIADO="ENUNCIADO";
	final String RESPUESTA="RESPUESTA";
	
	
	final String DATABASE_TABLE="LECCION";
	
	private MejoraTuInglesDatabaseHelper databaseHelper;
	private SQLiteDatabase db;
	private Context context;
	
	
	public LeccionAdapter(Context context) throws SQLException{
		this.context=context;
		open();
		
	}
	
	public LeccionAdapter open() throws SQLException{
		databaseHelper=new MejoraTuInglesDatabaseHelper(context);
		db=databaseHelper.getWritableDatabase();
		
		return this;
	}
	
	public void close() throws SQLException{
		db.close();
		databaseHelper.close();
	}
	
	public long insert(String nombre, String url) throws SQLException{
		ContentValues content=createContent(nombre,url);
		return db.insert(DATABASE_TABLE, null, content);
		
	}
	
	public List<Leccion> getAllLeccion(){
		Log.i("[MejoraTuIngles]","Recuperando lecciones disponibles");
		
		Cursor cursor=db.query(DATABASE_TABLE, new String[]{ID,NOMBRE,URL,"COMPLETADA","RESULTADO_TEST"}, null, null, null, null, null);
		List<Leccion> lecciones=new ArrayList<Leccion>();
		
		Log.i("[MejoraTuIngles]","Despues de consultar");
		
		if(!cursor.moveToNext()) return lecciones;
		do{
			Log.i("[MejoraTuIngles]","He recuperado algo");
			
			String id=cursor.getString(0);
			String nombre=cursor.getString(1);
			String url=cursor.getString(2);
			String completada=cursor.getString(3);
			double resultadoTest=cursor.getDouble(4);
			
			Leccion l=new Leccion();	
			l.setId(id);
			l.setNombre(nombre);
			l.setUrl(url);
			l.setCompletada(Integer.parseInt(completada));
			l.setResultadoTest(resultadoTest);
			
			lecciones.add(l);
			
			Log.d("[MejoraTuIngles]", "A�adiendo "+nombre+" a la lista");
		}while(cursor.moveToNext());
		
		cursor.close();
		
		close();
			
		Log.i("[MejoraTuIngles]","La lista de lecciones se ha generado correctamente.");
		
		return lecciones;
	}
	
	/**
	 * Recupera los ejercicios de una unidad did�ctica.
	 * 
	 * @param idLeccion
	 * @return listaEjercicios
	 */
	
	public Vector<Ejercicio> getEjercicios(int idLeccion){
		Log.i("LeccionAdapter","Recuperando ejercicios de la lecci�n: "+idLeccion);
		Vector<Ejercicio> ejercicios=null;
		
		String[] params={String.valueOf(idLeccion)};
		
		Cursor cursor=db.query("EJERCICIO", new String[]{ID,ENUNCIADO,"DATOS_ADICIONALES"}, "id_leccion=?", params, null, null, null);
		
		
		if(!cursor.moveToNext()) return ejercicios;
		
		ejercicios=new Vector<Ejercicio>();
		do{
			String id=cursor.getString(0);
			String enunciadoGeneral=cursor.getString(1);
			String datosAdicionales=cursor.getString(2);
			
			Ejercicio e=new Ejercicio();
			e.setId(id);
			e.setEnunciado(enunciadoGeneral);
			e.setDatosAdicionales(datosAdicionales);
			
			
			///Recuperar las preguntas
			
			Vector<Pregunta> preguntas=getPreguntas(id);
			e.setPreguntas(preguntas);
			
			ejercicios.add(e);
			
			Log.d("[LeccionAdapter]", "Anadiendo "+id+" a la lista");
		}while(cursor.moveToNext());
		
		cursor.close();
		close();
		
		return ejercicios;
	}
	
	public void completada(String id){
		String sql="update "+DATABASE_TABLE+" set completada = 1 where id = "+id;
		db.execSQL(sql);		
	}
	
	
	public Vector<Pregunta> getPreguntas(String idEjercicio){
		
		Log.i("LeccionAdapter","Recuperando ejercicios de la leccion: "+idEjercicio);
		Vector<Pregunta> preguntas=null;
		
		String[] params={idEjercicio};
		
		Cursor cursor=db.query("PREGUNTA", new String[]{ID,ENUNCIADO,RESPUESTA}, "id_ejercicio=?", params, null, null, null);
		
		
		if(!cursor.moveToNext()) return preguntas;
		
		preguntas=new Vector<Pregunta>();
		do{
			String id=cursor.getString(0);
			String enunciado=cursor.getString(1);
			String respuesta=cursor.getString(2);
			
			Pregunta p=new Pregunta();
			p.setId(id);
			p.setEnunciado(enunciado);
			p.setRespuesta(respuesta);
	
			preguntas.add(p);
			
			Log.d("[LeccionAdapter]", "A�adiendo "+id+" a la lista");
		}while(cursor.moveToNext());
		
		cursor.close();

		
		return preguntas;
		
	}
	
	
	
	/**
	 * Crea un ContentValue para operar con los m�todos CRUD de este adaptador.
	 */
	
	private ContentValues createContent(String nombre, String url){
		ContentValues content = new ContentValues();
		content.put("NOMBRE", nombre);
		content.put("URL", url);
		
		return content;
		
	}
	
	private ContentValues createContent(String id){
		ContentValues content=new ContentValues();
		content.put("ID",id);
		
		return content;
	}
	

}
